utils::globalVariables(c("Date",
                         "dyresmLAYER_HTS_Var",
                         "output_name",
                         "sim.var",
                         "temp.interpolated",
                         "obs.temp",
                         "Depth",
                         ".",
                         "Value",
                         "obs_temp",
                         "sim.cores",
                         "para.df",
                         "para.raw",
                         "dir.output",
                         "iteration"))
